@@ -1,4 +1,4 @@
 import { expectType } from 'tsd';
-import Clipboard from './clipboard';
+import * as Clipboard from './clipboard';
 
 expectType<Clipboard>(new Clipboard('.btn'));
